#ifndef GNM_SHEET_PRIVATE_H
#define GNM_SHEET_PRIVATE_H

struct _SheetPrivate {
	GnmRange	 unhidden_region;

	/* State of menu items */
	unsigned char    enable_showhide_detail;

	unsigned char	 recompute_visibility;
	unsigned char	 recompute_spans;
	unsigned char	 recompute_max_col_group;
	unsigned char	 recompute_max_row_group;
	unsigned char	 resize_scrollbar;
	unsigned char	 resize;
	GnmCellPos	 reposition_objects;
	unsigned char	 filters_changed;
};

/* for internal use only */
void gnm_sheet_cell_init (void);
void gnm_sheet_cell_shutdown (void);

#endif /* GNM_SHEET_PRIVATE_H */
